#!/usr/bin/python
#+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
#|R|a|s|p|b|e|r|r|y|P|i|-|S|p|y|.|c|o|.|u|k|
#+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
#
# ultrasonic_22.py
# Measure distance using an ultrasonic module
# in a loop.
#
# Basic program : Matt Hawkins
# Date          : 28/01/2013
# Additional elements : Han Doornheim
# Date		      : 11/05/2016

# -----------------------
# Import required Python libraries
# -----------------------
import time
import RPi.GPIO as GPIO
import subprocess as sp

# -----------------------
# Define some functions
# -----------------------
def measure():
  # This function measures a distance
  GPIO.output(GPIO_TRIGGER, True)
  time.sleep(0.00001)
  GPIO.output(GPIO_TRIGGER, False)
  start = time.time()

  while GPIO.input(GPIO_ECHO)==0:
    start = time.time()

  while GPIO.input(GPIO_ECHO)==1:
    stop = time.time()

  elapsed = stop-start
  distance = (elapsed * 34300)/2

  return distance

def measure_average():
  # This function takes 3 measurements and
  # returns the average.
  distance1=measure()
  time.sleep(0.1)
  distance2=measure()
  time.sleep(0.1)
  distance3=measure()
  distance = distance1 + distance2 + distance3
  distance = distance / 3
  return distance

# -----------------------
# Main Script
# -----------------------

# Use BCM GPIO references
# instead of physical pin numbers
GPIO.setmode(GPIO.BCM)

# set pieper
GPIO.setup(18,GPIO.OUT)

# Define GPIO to use on Pi
GPIO_TRIGGER = 23
GPIO_ECHO    = 24

# Clear screen
tmp = sp.call('clear',shell=True)

print ("\n\033[1;32mUltrasoon Meten\033[1;m")
print ("\033[1;32m===============\033[1;m\n")

a = input("Geef de alarmwaarde op: ")

print ("\nMeting start over 2 seconden\n") 
print ("----------------------------\n")
time.sleep(2)

#Switch peeper off"
GPIO.output(18,GPIO.LOW)

# Set pins as output and input
GPIO.setup(GPIO_TRIGGER,GPIO.OUT)  # Trigger
GPIO.setup(GPIO_ECHO,GPIO.IN)      # Echo

# Set trigger to False (Low)
GPIO.output(GPIO_TRIGGER, False)

# Wrap main content in a try block so we can
# catch the user pressing CTRL-C and run the
# GPIO cleanup function. This will also prevent
# the user seeing lots of unnecessary error
# messages.
try:

  while True:
    distance = measure_average()
    print ("Afstand : %.1f") % distance
    time.sleep(0.5)
    n = distance
    if n < a:
        print ("\033[1;41mWaarde is minder dan\033[1;m"),a
        GPIO.output(18,GPIO.HIGH)
        time.sleep(0.1)
        GPIO.output(18,GPIO.LOW)

except KeyboardInterrupt:
  # User pressed CTRL-C
  # Reset GPIO settings
  GPIO.cleanup()

